package com.fs.wx.sop.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.wx.sop.domain.WxSopUserInfo;

/**
 * 个微营期详情Service接口
 * 
 * @author 吴树波
 * @date 2026-02-24
 */
public interface IWxSopUserInfoService extends IService<WxSopUserInfo>{
    /**
     * 查询个微营期详情
     * 
     * @param id 个微营期详情主键
     * @return 个微营期详情
     */
    WxSopUserInfo selectWxSopUserInfoById(Long id);

    /**
     * 查询个微营期详情列表
     * 
     * @param wxSopUserInfo 个微营期详情
     * @return 个微营期详情集合
     */
    List<WxSopUserInfo> selectWxSopUserInfoList(WxSopUserInfo wxSopUserInfo);

    /**
     * 新增个微营期详情
     * 
     * @param wxSopUserInfo 个微营期详情
     * @return 结果
     */
    int insertWxSopUserInfo(WxSopUserInfo wxSopUserInfo);

    /**
     * 修改个微营期详情
     * 
     * @param wxSopUserInfo 个微营期详情
     * @return 结果
     */
    int updateWxSopUserInfo(WxSopUserInfo wxSopUserInfo);

    /**
     * 批量删除个微营期详情
     * 
     * @param ids 需要删除的个微营期详情主键集合
     * @return 结果
     */
    int deleteWxSopUserInfoByIds(Long[] ids);

    /**
     * 删除个微营期详情信息
     * 
     * @param id 个微营期详情主键
     * @return 结果
     */
    int deleteWxSopUserInfoById(Long id);
}
